# -*- coding: utf-8 -*-

from rest_framework import serializers
from thx.api.serializers import ThuxCreateSerializerMixin, ThuxUpdateSerializerMixin
from thx.role.core.serializers import ThuxRoleSerializerMixin

from ... import models


# VAT
class VatSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_vat_vat'
        model = models.Vat
        fields = '__all__'


class VatCreateSerializer(
    ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return VatSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_vat_vat_create'
        model = models.Vat
        fields = '__all__'


class VatUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return VatSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_vat_vat_update'
        model = models.Vat
        fields = '__all__'


class VatEnableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_vat_vat_enable'
        model = models.Vat
        fields = '__all__'

    def to_representation(self, instance):
        return VatSerializer(instance, context=self.context).data


class VatDisableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_vat_vat_disable'
        model = models.Vat
        fields = '__all__'

    def to_representation(self, instance):
        return VatSerializer(instance, context=self.context).data
